@@ -1,5 +1,5 @@
 package Test::Class::Moose;
-$Test::Class::Moose::VERSION = '0.58';
+$Test::Class::Moose::VERSION = '0.59';
 # ABSTRACT: Serious testing for serious Perl
 
 use 5.10.0;
@@ -245,7 +245,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
@@ -272,7 +272,7 @@ version 0.58
 
 =head1 DESCRIPTION
 
-See the L<Test::Class::Moose home page|http://ovid.github.io/test-class-moose/> for
+See the L<Test::Class::Moose home page|http://test-class-moose.github.io/test-class-moose/> for
 a summary.
 
 C<Test::Class::Moose> is a powerful testing framework for Perl. Out of the box
@@ -534,7 +534,9 @@ class's constructor. Here's a really dumb example:
  sub test_something { ... }
 
 The test runner will run all the test methods in your class I<once per
-instance>, and each instance will be run in its own subtest.
+instance>, and each instance will be run in its own subtest. You can
+dynamically decide to skip your test class completely by having
+C<_constructor_parameter_sets> return an empty list.
 
 Note that this feature has great potential for abuse, so use it
 cautiously. That said, there are cases where this feature can greatly simplify
@@ -562,6 +564,10 @@ If you wish to skip a class, set the reason in the C<test_startup> method.
         $test->test_skip("I don't want to run this class");
     }
 
+If you are using L<test class instances|/"TEST CLASS INSTANCES">, you
+can also make C<_constructor_parameter_sets> return an empty list,
+which will result in the class being skipped.
+
 If you wish to skip an individual method, do so in the C<test_setup> method.
 
     sub test_setup {
