@@ -1,5 +1,5 @@
 package Test::Class::Moose::Load;
-$Test::Class::Moose::Load::VERSION = '0.58';
+$Test::Class::Moose::Load::VERSION = '0.59';
 # ABSTRACT: Load L<Test::Class::Moose> classes automatically.
 
 use strict;
@@ -30,15 +30,24 @@ sub _load {
 
     # untaint that puppy!
     my ( $package ) = $_package =~ /^([[:word:]]+(?:::[[:word:]]+)*)$/;
-   
+
     # Filter out bad classes (mainly this means things in .svn and similar)
     return unless defined $package;
 
     unshift @INC => $dir unless $Added_to_INC{ $dir }++;
 
-    # either "require" it or "use" it with no import list. Otherwise, this
-    # module will inherit from Test::Class::Moose and break everything.
-    eval "use $package ()"; ## no critic
+    {
+        local $SIG{__DIE__} = sub {
+            undef $SIG{__DIE__};
+            require Carp;
+            local $Carp::CarpLevel = $Carp::CarpLevel + 1;
+            Carp::confess(@_);
+        };
+
+        # either "require" it or "use" it with no import list. Otherwise, this
+        # module will inherit from Test::Class::Moose and break everything.
+        eval "use $package ()";    ## no critic
+    }
     die $@ if $@;
 }
 
@@ -75,7 +84,7 @@ Test::Class::Moose::Load - Load L<Test::Class::Moose> classes automatically.
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
