@@ -1,5 +1,5 @@
 package Test::Class::Moose::Role::Executor;
-$Test::Class::Moose::Role::Executor::VERSION = '0.58';
+$Test::Class::Moose::Role::Executor::VERSION = '0.59';
 # ABSTRACT: Common code for Runner classes
 
 use 5.10.0;
@@ -53,6 +53,12 @@ sub _tcm_run_test_class {
             = $test_class->_tcm_make_test_class_instances(
             $self->test_configuration->args );
 
+        unless (%test_instances) {
+            my $message = "Skipping '$test_class': no test instances found";
+            $self->test_configuration->builder->plan(skip_all => $message);
+            return;
+        }
+
         foreach my $test_instance_name (sort keys %test_instances) {
             my $test_instance = $test_instances{$test_instance_name};
 
@@ -360,7 +366,7 @@ Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 AUTHOR
 
